PublicationLists extension

on

Properties

landmarks → List<Link>

Available on Publication, provided by the PublicationLists extension

Identifies fundamental structural components of the publication in order to enable Reading Systems to provide the User efficient access to them.
no setter
listOfAudioClips → List<Link>

Available on Publication, provided by the PublicationLists extension

no setter
listOfIllustrations → List<Link>

Available on Publication, provided by the PublicationLists extension

no setter
listOfTables → List<Link>

Available on Publication, provided by the PublicationLists extension

no setter
listOfVideoClips → List<Link>

Available on Publication, provided by the PublicationLists extension

no setter
pageList → List<Link>

Available on Publication, provided by the PublicationLists extension

Provides navigation to positions in the Publication content that correspond to the locations of page boundaries present in a print source being represented by this EPUB Publication.
no setter