PublicationAsset class abstract

Represents a digital medium (e.g. a file) offering access to a publication. */

Implementers

Constructors

PublicationAsset()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaType → Future<MediaType>
Media type of the asset.
no setter
name → String
Name of the asset, e.g. a filename. */
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFetcher(PublicationAssetDependencies dependencies, String? credentials) → Future<Try<Fetcher, OpeningException>>
Creates a fetcher used to access the asset's content.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTitle() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited