value property
Underlying enum value for Format. To be used with switch to make sure the cases match all values.
Implementation
final PublicationFormatEnum value;
Underlying enum value for Format. To be used with switch to make sure the cases match all values.
final PublicationFormatEnum value;