canPrintPageCount abstract method
Returns whether the user is allowed to print the given amount of pages.
This is more specific than the canPrint property, and can return false if the given
pageCount exceeds the allowed amount of pages to print.
To be used before attempting to launch a print job, for example.
Implementation
bool canPrintPageCount(int pageCount);