ZipLocalFile class

Inheritance
Implementers

Constructors

ZipLocalFile(int signature)

Properties

compressedSize ↔ int
getter/setter pair
compressionMethod ↔ int
getter/setter pair
crc32 ↔ int
getter/setter pair
extraField ↔ List<int>
getter/setter pair
extraFieldSize ↔ int
getter/setter pair
filename ↔ String
getter/setter pair
filenameSize ↔ int
getter/setter pair
generalFlag ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCentralDirectory → bool
no setterinherited
isCentralDirectoryEnd → bool
no setterinherited
isLocalFile → bool
no setterinherited
lastModDate ↔ int
getter/setter pair
lastModTime ↔ int
getter/setter pair
offsetEnd ↔ int
getter/setter pairinherited
offsetStart ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → int
finalinherited
uncompressedSize ↔ int
getter/setter pair
versionToExtract ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes the object to its JSON representation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited